# OnboardUserRequest

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**email** | **str** | Max length 100 characters | 
**first_name** | **str** | Max length 50 characters | 
**last_name** | **str** | Max length 50 characters | 
**organisation_reference** | **str** | Max length 20 characters | 
**roles** | [**list[Role]**](Role.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

